@@ -11,8 +11,6 @@ import subprocess
 import time
 import urllib
 
-import chardet
-
 
 def openWindowsFolder(folder):
     os.system(f"start explorer {folder}")
@@ -22,6 +20,10 @@ def getPath(basePath, *parList):
     return os.path.abspath(os.path.join(basePath, *parList))
 
 
+def getDesktopPath(*parList):
+    return getPath(os.path.expanduser("~"), "Desktop", *parList)
+
+
 def writeFile(file, data, encoding='utf8', newline='\n'):
     makeFolder(os.path.dirname(file))
     with open(file, 'w', encoding=encoding, newline=newline) as f:
@@ -187,13 +189,7 @@ def getClassFullName(classItem):
     return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
 
 
-def decode(value):
-    data = chardet.detect(value)
-    encoding = data["encoding"] or "utf8"
-    return value.decode(encoding)
-
-
-def getTempWorkspace(clearOneDayBefore=True):
+def makeTempWorkspace(clearOneDayBefore=True):
     baseWorkspaceFoler = getPath(os.path.expanduser("~"), "beniutils.workspace")
     makeFolder(baseWorkspaceFoler)
     nowTime = int(time.time() * 10000000)
@@ -225,6 +221,7 @@ def execute(*pars, showCmd=True, showOutput=False, ignoreError=False):
     outBytes, errBytes = p.communicate()
     p.kill()
     if showOutput:
+        from .bytes import decode
         outStr = decode(outBytes).replace("\r\n", "\n")
         errStr = decode(errBytes).replace("\r\n", "\n")
         if outStr:
