@@ -8,9 +8,9 @@ from .print import (FOREGROUND_DARKPINK, FOREGROUND_DARKRED,
 
 _loggerName = 'beniutils'
 
-countLogWarning = 0
-countLogError = 0
-countLogCritical = 0
+_countWarning = 0
+_countError = 0
+_countCritical = 0
 
 
 def initLogger(loggerName=None, loggerLevel=None, logFile=None):
@@ -42,16 +42,16 @@ def initLogger(loggerName=None, loggerLevel=None, logFile=None):
                 # issue 35046: merged two stream.writes into one.
                 func = self.stream.write
                 if record.levelno == logging.WARNING:
-                    global countLogWarning
-                    countLogWarning += 1
+                    global _countWarning
+                    _countWarning += 1
                     setPrintColor(FOREGROUND_DARKYELLOW)
                 elif record.levelno == logging.ERROR:
-                    global countLogError
-                    countLogError += 1
+                    global _countError
+                    _countError += 1
                     setPrintColor(FOREGROUND_DARKRED)
                 elif record.levelno == logging.CRITICAL:
-                    global countLogCritical
-                    countLogCritical += 1
+                    global _countCritical
+                    _countCritical += 1
                     setPrintColor(FOREGROUND_DARKPINK)
                 func(msg)
                 resetPrintColor()
@@ -92,3 +92,30 @@ def error(msg, *args, **kwargs):
 
 def critical(msg, *args, **kwargs):
     logging.getLogger(_loggerName).critical(msg, *args, **kwargs)
+
+
+def getCountWarning():
+    return _countWarning
+
+
+def setCountWarning(value):
+    global _countWarning
+    _countWarning = value
+
+
+def getCountError():
+    return _countError
+
+
+def setCountError(value):
+    global _countError
+    _countError = value
+
+
+def getCountCritical():
+    return _countCritical
+
+
+def setCountCritical(value):
+    global _countCritical
+    _countCritical = value
